/**
 * 
 */
package ch.psi.daq.queryrest.response;

import java.io.OutputStream;
import java.util.zip.GZIPOutputStream;

import javax.servlet.http.HttpServletResponse;

import org.springframework.http.MediaType;

import ch.psi.daq.query.model.impl.DAQQuery;


/**
 * @author zellweger_c
 *
 */
public abstract class AbstractResponseStreamWriter implements ResponseStreamWriter {

   public static final String CONTENT_TYPE_CSV = "text/csv";
   protected static final String CONTENT_TYPE_JSON = MediaType.APPLICATION_JSON_VALUE;

   /**
    * Configures the output stream and headers according to whether compression is wanted or not.
    * <p>
    * In order not to lose the information of the underlying type of data being transferred, the
    * Content-Type header stays the same but, if compressed, the content-encoding header will be set
    * accordingly.
    * 
    * @param query
    * @param response
    * @return
    * @throws Exception
    * 
    * @see http://tools.ietf.org/html/rfc2616#section-14.11 and
    * @see http://tools.ietf.org/html/rfc2616#section-3.5
    */
   protected OutputStream handleCompressionAndResponseHeaders(DAQQuery query, HttpServletResponse response,
         String contentType) throws Exception {
      OutputStream out = response.getOutputStream();

      response.addHeader("Content-Type", contentType);
      if (query.isCompressed()) {
         response.addHeader("Content-Disposition", "attachment; filename=data.gz");
         response.addHeader("Content-Encoding", "gzip");
         out = new GZIPOutputStream(out);
      } else {
         response.addHeader("Content-Disposition", "attachment; filename=data.csv");
      }

      return out;
   }

}
